import React, { Component } from 'react'

import { Upload, Modal } from 'antd';
import { PlusOutlined } from '@ant-design/icons';

import type { PicturesWallType } from './data'

import { baseUrl } from '@/utils/request'

function getBase64(file) {
    return new Promise((resolve, reject) => {
      const reader = new FileReader();
      reader.readAsDataURL(file);
      reader.onload = () => resolve(reader.result);
      reader.onerror = error => reject(error);
    });
  }

// {
//     uid: '-1',
//     name: 'image.png',
//     status: 'done',
//     url: 'https://zos.alipayobjects.com/rmsportal/jkjgkEfvpUPVyRjUImniVslZfWPnJuuZ.png',
// }

class PicturesWall extends Component<PicturesWallType> {
    state = {
      previewVisible: false,
      previewImage: '',
      previewTitle: '',
      fileList: [],
    };
    

    componentDidMount () {
        const { imgUrl } = this.props
        console.log(imgUrl);
          if (!imgUrl) return
          this.setState({
            fileList: [
                {
                    uid: '-1',
                    name: 'image.png',
                    status: 'done',
                    url: imgUrl,
                },
            ]
        })
    }

    handleCancel = () => this.setState({ previewVisible: false });
  
    handlePreview = async (file: Record<string, any>) => {
      if (!file.url && !file.preview) {
        file.preview = await getBase64(file.originFileObj);
      }
  
      this.setState({
        previewImage: file.url || file.preview,
        previewVisible: true,
        previewTitle: file.name || file.url.substring(file.url.lastIndexOf('/') + 1),
      });
    };
  
    handleChange = ({ fileList }: {fileList: Record<string, any>}): void => {
        console.log(fileList);
        
        this.setState({ fileList })

        if (fileList[0]?.status === 'done') {
            // fileList.response.data
            this.props.setCoverFn(fileList[0].response.data)
        }
    };
    render() {
      const { previewVisible, previewImage, fileList, previewTitle } = this.state;
      const uploadButton = (
        <div>
          <PlusOutlined />
          <div style={{ marginTop: 8 }}>上传贴吧图标</div>
        </div>
      );
      const { maxCount } = this.props
      return (
        <>
          <Upload
            action={`${baseUrl}/forum/file/uploadImage`}
            listType="picture-card"
            fileList={fileList}
            maxCount={maxCount}
            onPreview={this.handlePreview}
            onChange={this.handleChange}
          >
            {fileList.length >= maxCount ? null : uploadButton}
          </Upload>
          <Modal
            visible={previewVisible}
            title={previewTitle}
            footer={null}
            onCancel={this.handleCancel}
          >
            <img alt="example" style={{ width: '100%' }} src={previewImage} />
          </Modal>
        </>
      );
    }
  }

  
  export default PicturesWall
