import React, { useEffect, useState } from 'react';
import { Col, Modal, Row, Image, Avatar, Space, Card, Descriptions, Tag, Spin } from 'antd';
import { getAgentDetail } from '@/services/agent';

import type { roleListType } from './index';

type DetailModalType = {
  visible: boolean;
  id: string;
  closeModal: () => void;
};

type followBarsType = {
  avatarUrl: string;
  label: string;
  [key: string]: any;
};

type userInfoType = {
  id: string;
  avatarUrl: string;
  nickName: string;
  authRoles: any;
  phoneNumber: string;
  followBarNum: number | null;
  followBars: followBarsType[];
  [key: string]: any;
};

const DetailModal: React.FC<DetailModalType> = ({ visible, id, closeModal }) => {
  const [userInfo, setUserInfo]: [userInfoType, (params: userInfoType) => void] = useState<
    Record<string, any>
  >({});
  const [spinning, setSpinning] = useState<boolean>(false);

  // 获取详情
  const GetAgentDetail = async () => {
    setSpinning(true);
    const { code, data } = await getAgentDetail(id);
    setSpinning(false);
    if (code === 0) {
      setUserInfo(data);
      console.log(userInfo.authRoles, '获取详情');
    }
  };

  useEffect(() => {
    GetAgentDetail();
  }, []);

  // 渲染关注的贴吧
  const renderFollowBar = (): React.ReactNode => {
    return (
      <Row gutter={[16, 16]}>
        {userInfo.followBars &&
          userInfo.followBars.map((item) => (
            <Col key={item.id} span={4}>
              <Space direction="vertical" align="center">
                <Image width={50} height={50} src={item.avatarUrl} alt="我炸裂了"></Image>
                <span>{item.label}</span>
              </Space>
            </Col>
          ))}
      </Row>
    );
  };

  // 渲染用户角色
  const renderAuthRoles = (): React.ReactNode => {
    return (
      <Space>
        {userInfo.authRoles.map((item: roleListType) => (
          <Tag key={item.id} color="magenta">
            {item.roleLabel}
          </Tag>
        ))}
      </Space>
    );
  };

  return (
    <Modal title="详细信息" visible={visible} width={1200} onOk={closeModal} onCancel={closeModal}>
      <Spin spinning={spinning}>
        <Row gutter={16}>
          <Col span={8}>
            <Space direction="vertical" align="center">
              <Avatar
                src={userInfo.avatarUrl}
                alt="我炸裂了"
                size={{ xs: 24, sm: 32, md: 40, lg: 64, xl: 80, xxl: 100 }}
              />
              <Descriptions layout="horizontal" column={1}>
                <Descriptions.Item span={1} label="姓名">
                  {userInfo.nickName}
                </Descriptions.Item>
                <Descriptions.Item span={1} label="手机号">
                  {userInfo.phoneNumber}
                </Descriptions.Item>
                <Descriptions.Item span={1} label="地址">
                  {userInfo.region || '暂无地址'}
                </Descriptions.Item>
                <Descriptions.Item span={1} label="角色">
                  {userInfo.authRoles && renderAuthRoles()}
                </Descriptions.Item>
              </Descriptions>
            </Space>
          </Col>
          <Col span={16}>
            <Card
              title={`关注的贴吧板块${userInfo?.followBars?.length}`}
              style={{ width: '100%', height: '100%' }}
            >
              {renderFollowBar()}
            </Card>
          </Col>
        </Row>
      </Spin>
    </Modal>
  );
};
export default DetailModal;
