import React, { useState, useEffect } from 'react'
import { Card , Row, Col, Table, Input, Button, message, Space} from 'antd'
import { PageContainer } from '@ant-design/pro-layout'

import { getComplaint } from '@/services/complaint'

import { enablePosts } from '@/services/tieba'
import type { getComplaintType, articleTypeEnum } from './data'

import AdminModal from './modal'



const Complaint: React.FC = () => {

    const [articleType, setArticleType] = useState('POSTS')
    const [label, setLabel] = useState('')

    const [complaintList, setComplaintList] = useState([])
    const [total, setTotal] = useState(0)

    const [complaintData, setComplaintData] = useState({})

    const [visible, setVisible] = useState(false)

    const [ loading, setLoading ] = useState(false)

    const [curPage, setCurPage] = useState(1)

     // 获取帖子
    const GetComplaint = async (): Promise<void> => {
        const $par = {
            articleType,
            label,
            curPage: 1
        }
        setLoading(true)
        const { code, data } = await getComplaint($par as getComplaintType)
        setLoading(false)
        if (code === 0) {
            console.log(data);
            const { records, total: Total} = data
            setComplaintList(records)
            setTotal(Total)
        }
    }

    // 封禁 或者 解封帖子
    const EnablePosts = async (record: Record<string, any>): Promise<void> => {
       const $par = {
         id: record.id,
         enable: record.itemEnable ? 0 : 1,
         type: articleType === 'POSTS'? 0 : 1
       }
       const { code } =  await enablePosts($par)
       if (code === 0) {
           message.success('操作成功')
       }
       GetComplaint()
    }


    useEffect( () => {
        GetComplaint()
    }, [articleType, curPage])

    // 切换tab
    const onTabChange = (key: string): void => setArticleType(key)
    // 标题
    const changeLabel = (e: React.ChangeEvent<HTMLInputElement>): void =>  setLabel(e.target.value)

    // 打开弹窗
    const openModal = (record: Record<string, any>): void => {
        setVisible(true)
        setComplaintData(record)
    }
    // 关闭弹窗
    const closeModal = (): void => setVisible(false)

    // 分页
    const changePagination = (page: number): void => setCurPage(page) 
    return (
        <PageContainer
            title="投诉管理"
            onTabChange={onTabChange}
            tabList={[
                {
                    key: 'POSTS',
                    tab: '帖子'
                },
                {
                    key: 'ISSUES',
                    tab: '问答'
                }
            ]}
        >
            <Card>
                <Row justify="space-between">
                    <Col >
                       <Input onChange={changeLabel} placeholder={ articleType === 'POSTS' ? '帖子标题' : '问答标题'} />
                    </Col>
                    <Col>
                        <Button type="primary" onClick={GetComplaint}>搜索</Button>
                    </Col>
                </Row>
                <Table dataSource={complaintList} style={{marginTop: 20}} loading={loading} pagination={{total, onChange: changePagination}}>
                    <Table.Column key="itemLabel" dataIndex="itemLabel" title="标题"></Table.Column>
                    <Table.Column key="reason" dataIndex="reason" title="投诉原因"></Table.Column>
                    <Table.Column key="itemAuthor" dataIndex="itemAuthor" title="投诉人"></Table.Column>
                    <Table.Column key="reportNum" dataIndex="reportNum" title="投诉次数"></Table.Column>
                    <Table.Column key="action" dataIndex="action" title="操作"
                        render={ (text, record: Record<string, any>) => (
                            <Space>
                                <a onClick={() => openModal(record)}>查看</a>
                                <a onClick={() => EnablePosts(record)}>{record.itemEnable ? '封禁' : '恢复'}</a>
                            </Space>
                        )}
                    ></Table.Column>
                </Table>
            </Card>
            {/* 弹窗 */}
            {
                visible && <AdminModal
                                visible={visible} 
                                articleType={articleType as articleTypeEnum}  
                                complaintData={complaintData}
                                closeModal={closeModal}
                            />
            }
            
        </PageContainer>
    )
}


export default Complaint