import React, { Component } from 'react';
import { Row, Col, Card, Space, Select, Button, Input, Table, Image, message } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import { getPlate, postOrPutPlate, changeTiebaState } from '@/services/tieba';
import ModalForm from './ModalForm';

import type { ColumnType, typeEnum, postOrPutPlateType } from './data';

import { getRoleList } from '@/services/role';

class Plate extends Component<React.Component> {
  state = {
    queryParams: {
      curPage: 1,
      label: '',
      typeId: '',
    },
    id: '',
    visible: false,
    type: 0,
    form: {},
    total: 0,
    plateList: [],
    roleList: [],
  };

  componentDidMount() {
    this.getPlate();
    this.GetRoleList();
  }

  // 改变上架状态
  changeTiebaState = async (record: Record<string, any>): Promise<void> => {
    const $par = {
      id: record.id,
      state: record.state === 1 ? 0 : 1,
    };
    const { code, data } = await changeTiebaState($par);
    if (code === 0) {
      console.log(data);
      message.success(record.state === 1 ? '下架成功' : '上架成功');
    }
    this.getPlate();
  };

  // 选择认证角色
  changeRole = (value: string): void => {
    console.log(value);

    this.setState({
      queryParams: { ...this.state.queryParams, typeId: value },
    });
  };
  // 搜索
  onSearch = (): void => {
    this.getPlate();
  };

  // 打开弹窗
  openModal = (type: typeEnum, record?: ColumnType): void => {
    console.log(record, type, 'record');

    this.setState({
      type,
      visible: true,
      form: record,
      id: record?.id,
    });
  };
  // 关闭弹窗
  closeModal = (): void => this.setState({ visible: false });

  // 提交表单
  changeForm = async (params: postOrPutPlateType): Promise<void> => {
    const { code, data } = await postOrPutPlate({
      ...params,
      type: this.state.type,
      id: this.state.id,
    });
    console.log(code, data, '提交表单');

    if (code === 0) {
      console.log(data);
      message.success(this.state.type === 0 ? '新增成功' : '编辑成功');
      this.setState({
        visible: false,
      });
    }
    this.getPlate();
  };

  // 用户角色
  GetRoleList = async (): Promise<void> => {
    const { code, data } = await getRoleList({ curPage: 1 });
    if (code === 0) {
      console.log(data);
      const { records } = data;
      this.setState({
        roleList: records,
      });
    }
  };

  // 获取板块列表
  getPlate = async (): Promise<void> => {
    const { queryParams } = this.state;
    const { code, data } = await getPlate(queryParams);
    if (code === 0) {
      const { records, total } = data;
      console.log(records, 'recordsrecordsrecords');

      this.setState({
        plateList: records,
        total,
      });
    }
  };

  render() {
    const { plateList, visible, type, form, roleList, queryParams } = this.state;
    const { openModal, changeForm, closeModal, onSearch, changeRole, changeTiebaState } = this;
    return (
      <PageContainer title="贴吧板块管理">
        <Card>
          <Row justify="space-between">
            <Col>
              <Space>
                <Select
                  style={{ width: 200 }}
                  placeholder="请输入认证角色"
                  onChange={changeRole}
                  value={queryParams.typeId}
                  allowClear
                >
                  {roleList.length &&
                    roleList.map((item: Record<string, any>) => (
                      <Select.Option key={item.id} value={item.id}>
                        {item.label}
                      </Select.Option>
                    ))}
                </Select>
                <Input
                  value={queryParams.label}
                  onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
                    this.setState({ queryParams: { ...queryParams, label: e.target.value } });
                  }}
                  placeholder="请输入贴吧板块名称"
                />
              </Space>
            </Col>
            <Col>
              <Space>
                <Button
                  danger
                  onClick={() => {
                    this.setState({ queryParams: { ...queryParams, label: '', typeId: '' } });
                  }}
                >
                  重置
                </Button>
                <Button type="primary" onClick={onSearch}>
                  搜索
                </Button>
                <Button onClick={() => openModal(0, {} as ColumnType)}>创建</Button>
              </Space>
            </Col>
          </Row>
          <Table dataSource={plateList} style={{ marginTop: 20 }}>
            <Table.Column<ColumnType>
              key="avatarUrl"
              title="贴吧图标"
              render={(text, record): React.ReactNode => (
                <Image width={50} height={50} preview src={text.avatarUrl} alt="我炸裂了" />
              )}
            ></Table.Column>
            <Table.Column<ColumnType> key="label" dataIndex="label" title="贴吧名"></Table.Column>
            <Table.Column<ColumnType>
              key="categoryLabel"
              dataIndex="categoryLabel"
              title="分类名"
            ></Table.Column>
            <Table.Column<ColumnType>
              key="creator"
              dataIndex="creator"
              title="创建人"
            ></Table.Column>
            <Table.Column<ColumnType>
              key="postNum"
              dataIndex="postNum"
              title="帖子数量"
            ></Table.Column>
            <Table.Column<ColumnType>
              key="action"
              dataIndex="action"
              title="操作"
              render={(text, record): React.ReactNode => (
                <Space>
                  {/* <a>查看</a> */}
                  <a onClick={() => openModal(1, record)}>编辑</a>
                  <a onClick={() => changeTiebaState(record)}>
                    {record.state === 0 ? '发布' : '下架'}
                  </a>
                </Space>
              )}
            ></Table.Column>
          </Table>
        </Card>
        {/* 新增或者编辑弹窗 */}
        {visible && (
          <ModalForm
            roleList={roleList}
            type={type}
            formData={form as postOrPutPlateType}
            visible={visible}
            changeForm={changeForm}
            closeModal={closeModal}
          />
        )}
      </PageContainer>
    );
  }
}
export default Plate;
